--------------
-- welche Indexes und die Gre davon
-- sys.dm_db_index_physical_stats
-- aktuelle Datenbank
---------------------
use AdventureWorks
go
SELECT 
	SCHEMA_NAME(T.schema_id) as Schemaname,
	T.[name] as TableName,
    I.[name] as IndexName,
    I.type_desc as IndexType,
    (P.page_count * 8.0) AS space_used_in_kb,
    (P.page_count * 8.0 / 1024.0) AS space_used_in_mb
FROM sys.indexes AS I
		INNER JOIN sys.dm_db_index_physical_stats(db_id(), null, null, null, null) as P on 
			I.[object_id] = P.[object_id] and 
			I.[index_id] = P.[index_id]
		LEFT JOIN sys.tables as T ON
			I.object_id = T.object_id
ORDER BY space_used_in_mb DESC

---------------------
-- Unbenutze Tabellen und Indexies
---------------------
SELECT	object_name(i.object_id) AS ObjectName
		, i.name as IndexName
		, i.index_id 
FROM	sys.indexes as i 
	INNER JOIN sys.objects as o ON	o.object_id = i.object_id
LEFT JOIN sys.dm_db_index_usage_stats as s ON	i.object_id=s.object_id 
												AND	i.index_id=s.index_id
												AND	database_id = DB_ID()  
WHERE	objectproperty(o.object_id,'IsUserTable') = 1
AND		s.index_id IS NULL
ORDER BY objectname,i.index_id,indexname ASC

---------------------
-- Wie werden die Indexies verwenden, wenn Sie verwendet werden
---------------------

SELECT	object_name(s.object_id) AS ObjectName
		, s.object_id
		, i.name as IndexName
		, i.index_id
		, user_seeks
		, user_scans
		, user_lookups
		, user_updates
FROM	sys.dm_db_index_usage_stats as s 
INNER JOIN sys.indexes as i
	ON	i.object_id = s.object_id
	AND i.index_id = s.index_id
WHERE	database_id = db_id ()
		AND		objectproperty(s.object_id,'IsUserTable') = 1
ORDER BY (user_seeks + user_scans + user_lookups + user_updates) ASC

---------------------
--Mehr Index Scan als Index Seek
---------------------
SELECT	object_name(s.object_id) AS ObjectName
		, s.object_id
		, i.name as IndexName
		, i.index_id
		, user_seeks
		, user_scans
		, user_lookups
		, user_updates
FROM	sys.dm_db_index_usage_stats s 
INNER JOIN sys.indexes i
	ON	i.object_id = s.object_id
	AND i.index_id = s.index_id
WHERE	database_id = db_id ()
AND		objectproperty(s.object_id,'IsUserTable') = 1
AND		user_scans > user_seeks
ORDER BY user_scans DESC
